@@ -10,7 +10,14 @@ from . import configs, layers
 
 
 class Placeholder:
-    def __init__(self, value: torch.Tensor, parents=tuple(), depth=0, layer=None, batch_size_known=False):
+    def __init__(
+        self,
+        value: torch.Tensor,
+        parents=tuple(),
+        depth=0,
+        layer=None,
+        batch_size_known=False,
+    ):
         """Node of a Functional Model.
 
         This might represent input or intermediate values of the neural network.
@@ -186,15 +193,15 @@ class Placeholder:
     def __pow__(self, other):
         if isinstance(other, Placeholder):
             assert self.shape == other.shape, "Shapes do not match for the operation!"
-            return self.apply_layer(layers.AnyOpLayer(op=lambda x, y: x ** y), other)
+            return self.apply_layer(layers.AnyOpLayer(op=lambda x, y: x**y), other)
         else:
-            return self.apply_layer(layers.AnyOpLayer(op=lambda x: x ** other))
+            return self.apply_layer(layers.AnyOpLayer(op=lambda x: x**other))
 
     def __rpow__(self, other):
         if isinstance(other, Placeholder):
             return other.__pow__(self)
         else:
-            return self.apply_layer(layers.AnyOpLayer(op=lambda x: other ** x))
+            return self.apply_layer(layers.AnyOpLayer(op=lambda x: other**x))
 
     def __sub__(self, other):
         if isinstance(other, Placeholder):
