@@ -22,3 +22,13 @@ def model_similar(a, b):
     if sorted(get_parameter_shapes(a)) != sorted(get_parameter_shapes(b)):
         return False
     return True
+
+
+def hash_tensor(tensor):
+    return hash(" ".join([str(value) for value in tensor.flatten()]))
+
+
+def model_hashes_identical(a, b):
+    hashes_a = [hash_tensor(p) for p in a.parameters()]
+    hashes_b = [hash_tensor(p) for p in b.parameters()]
+    return set(hashes_a) == set(hashes_b)
